# Digger
A toolkit for the automatic annotation of V,D and J genes and associated features in IG receptor genomic loci.

For more details, please see the [documentation](https://williamdlees.github.io/digger/index.html).

Changes in v 0.5.5:
- speed optimisation for dig_sequence
- allow find_alignments to be called without a -ref parameter

Changes in V 0.5.4:
- Minor fixes to handling of non-functional sequences

Changes in V 0.5.3:
- Fixes to annotation in reverse-sense: false positives were not being filtered correctly
- Introduction of dig_sequence: targeted annotation of an identified sequence

Changes in V 0.5.1:
- (internal only) - Refactored elements of the code to make it more modular and easier to maintain.
